# TenantStatus


## Properties
Name | Type | Description | Notes
------------ | ------------- | ------------- | -------------
**control_status** | [**ControlStatus**](ControlStatus.md) |  | [optional] 
**getv_edge_health** | [**VEdgeHealth**](VEdgeHealth.md) |  | [optional] 
**getv_smart_status** | [**VSmartStatus**](VSmartStatus.md) |  | [optional] 
**site_health** | [**SiteHealth**](SiteHealth.md) |  | [optional] 
**tenant_id** | **str** |  | [optional] 
**tenant_name** | **str** |  | [optional] 
**any string name** | **bool, date, datetime, dict, float, int, list, str, none_type** | any string name can be used but the value must be the correct type | [optional]

[[Back to Model list]](../README.md#documentation-for-models) [[Back to API list]](../README.md#documentation-for-api-endpoints) [[Back to README]](../README.md)


